@@ -1,6 +1,8 @@
 import os
 import uuid
 
+__version__ = "0.1.3"
+
 ROOT = os.path.dirname(os.path.abspath(__file__))
 QUEUE_DIR = os.path.join(ROOT, f'queue_manager')
 DB_DIR = os.path.join(ROOT, f'db.json')
@@ -22,5 +24,3 @@ opener.addheaders = [
     ('Accept-Encoding', 'gzip, deflate, br')
 ]
 urllib.request.install_opener(opener)
-
-from torchvision import datasets
\ No newline at end of file
