@@ -25,6 +25,8 @@ def on_message(client: mqtt.Client, userdata, msg):
 
         if command == 'train':
             add_task(msg_dict)
+        elif command == 'ping':
+            reply_to_server({'success': True})
         elif command == 'search':
             # Look for databases corresponding with tags
             databases = search_by_tags(msg_dict['tags'])
